function eff_dim = effective_dim(mat, b)
%EFF_DIM Effective dimension of estimation problem.
%   D = EFF_DIM(Q, B) is the modified effective dimension of the estimation
%   problem, with discrimination parameter B. When B is not specified, -1
%   is assumed, yielding the (unmodified) effective dimension.

%   Asaf Elron and Guy Leibovitz, 2008.
%   Based on Ben-Haim & Eldar, Blind Minimax Estimation", IEEE TIT, 2007.

% handle input parameters
if (~ exist('b', 'var'))
    b = -1;
end;

% take Q to the power B
mat = mat^b;

% calculate (modified) effective dimension
eff_dim = trace(mat) / max(eig(mat)); 

end
