% Demostrates the use of the function compare_estimators()

%   Asaf Elron and Guy Leibovitz, 2008.
%   [1] Ben-Haim & Eldar, Blind Minimax Estimation", IEEE TIT, 2007.

dimension = 15; % length of parameter vector
H = eye(dimension); % model matrix
Cw = diag([1,1,1,1, 0.5, 0.2,0.2,0.2,0.2, 0.1,0.1,0.1,0.1, 0.05,0.05]); % used in [1]

noise_realizations = 1000; % number of noise realizations
different_unknown_vectors = 10; % number of different values of unknown vector

pattern = randn(dimension, different_unknown_vectors); % a few different values of unknown vector

getX = @(i) pattern(:, mod(i,size(pattern,2)) +1); % cyclicly supply a value for the unknown vector
getY = @(i) H*getX(i) + Cw^0.5 * randn(dimension, 1); % cyclicly supply a noisy measurement of the unknown vector

% compare estimators and report some statistics
stats = compare_estimators(H, Cw, getX, getY, noise_realizations, -1, 'lse')

% report some more statistics
normalized_SBM_squared_error = stats.means_of_squared_errors(2) / stats.epsilon0
normalized_EBM_squared_error = stats.means_of_squared_errors(3) / stats.epsilon0

EBME_outperformance_of_SBME = normalized_SBM_squared_error / normalized_EBM_squared_error
